tlslite.errors.TLSError

Package tlslite :: Module errors :: Class TLSError |
[hide private]
[frames] | no frames]

# Class TLSError

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                                  TLSError

Known Subclasses:
  - TLSAbruptCloseError
  - , TLSAlert
  - , TLSAuthenticationError
  - , TLSClosedConnectionError
  - , TLSFaultError
  - , TLSUnsupportedError

Base class for all TLS Lite exceptions.

Instance Methods | [hide private]
__str__(self) "At least print out the Exception time for str(...). | source code
Inherited from `exceptions.Exception`: `__init__`, `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details | [hide private]

### __str__(self) (Informal representation operator) | source code
"At least print out the Exception time for str(...). Overrides: object.__str__